#!/bin/bash
# Author : Guth (guth@ploposor.com)
# URL : http://www.packetfactory.net/libnet/dist/libnet-1.1.2.1.tar.gz

# program name/version
FilenameFromUrl="$(grep 'U[R]L' $0 | rev | cut -d '/' -f1 | rev)"
softname="$(echo $FilenameFromUrl | cut -d '-' -f1)"
softversion="$(echo $FilenameFromUrl | cut -d '-' -f2 | cut -d '.' -f -4 )"
#softversion='1.1.4'
#softname='dsniff'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='54.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="${softname}-$softversion-$arch-$packageversion"
srcpkg="$buildir/$FilenameFromUrl"

if ! [ -f "$FilenameFromUrl" ]; then
    echo "Downloading the program tarball...$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)"
    wget "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" ||exit 0
fi


# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest ||exit 0
rm -f $package.* ||exit 0
mkdir -p $dest/usr/{bin,man/man1,man/man3} ||exit 0
mkdir -p $dest/install ||exit 0
mkdir -p $dest/usr/src/$softname-$softversion ||exit 0
mkdir -p $dest/usr/doc/$softname-$softversion ||exit 0

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
      |----handy-ruler--------------------------------------------------------|
libnet: Libnet (Network library to forge packets) 
libnet:
libnet: Libnet is a high-level API (toolkit) allowing the application 
libnet: programmer to construct and inject network packets. It provides a
libnet: portable and simplified interface for low-level network packet
libnet: shaping, handling and injection.
libnet:
libnet:
libnet:
libnet:
libnet: 
EOF

# extract sources
echo "extracting ..."
srcdir="$softname"
cd $buildir ||exit 0
rm -rf $srcdir ||exit 0
tar zxf $FilenameFromUrl ||exit 0
cd $srcdir ||exit 0

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

echo "configuring ..."

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure --prefix=/usr \
   --sysconfdir=/etc \
   --localstatedir=/var \
   --mandir=/usr/man  || exit 0

# compile package
make $ntasks ||exit 0

# install package to the target directory
make install DESTDIR=$dest ||exit 0

# copy the doc files

cp libnet-config $dest/usr/bin

cp -a \
 README VERSION sample \
 $dest/usr/doc/$softname-$softversion ||exit 0

(
    cd doc
    cp -a \
	BUGS CHANGELOG CONTRIB COPYING \
	DESIGN_NOTES  MIGRATION PACKET_BUILDING \
	PORTED RAWSOCKET_NON_SEQUITUR TODO html \
	libnet.doxygen.conf \
	$dest/usr/doc/$softname-$softversion ||exit 0
    )

cp -a doc/man/man3/* $dest/usr/man/man3/ ||exit 0

# strip executables
echo "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages and info files
echo "gzipping ..."
gzip -9 $dest/usr/man/*/*
chown -R root.root $dest/usr/man/*/*
find $dest/usr/doc/ -type f -exec chmod 644 {} \;


# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/$0 $dest/usr/src/$softname-$softversion ||exit 0
chown -R root.root $dest/usr/src/$softname-$softversion ||exit 0

# change files ownerships for $dest/usr/sbin
chown -R root.root $dest/usr/bin ||exit 0

# make the package and move it to the build directory

#------------------( Create The *.dep File )
echo "creating .dep ..."
cd $dest
requiredbuilder -z $dest > $buildir/$package.dep ||exit 0


cd $dest
/sbin/makepkg -l y -c n $package.tgz ||exit 0
mv $package.tgz $buildir ||exit 0

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir ||exit 0
md5sum $package.tgz > $package.md5 ||exit 0


if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

echo "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" > $package.src
echo "http://zen-repo.meticul.eu/zen_stuffs/guth/packages/libnet/$0" >> $package.src
